@@ -15,8 +15,8 @@ class StationA(Station):
         dest_headroom_height: float = 2,
         dest_top_height: float = 5,
         dest_multi_headroom_height: float = 2,
-        drop_loc_l: float = 0,
-        drop_loc_r: float = 0,
+        drop_loc_l: float = -10,
+        drop_loc_r: float = 30,
         drop_threshold: int = 296,
         hover_height: float = -2,
         ic_capacity: float = 180,
@@ -307,7 +307,8 @@ class StationA(Station):
         return dest == self._dest_plate[self._positive_control_well]
     
     def non_control_positions(self, sources=None, dests=None):
-        """Returns the iterator for the source/dest couples, excluding the couple where the destination is meant for the positive control.
+        """Returns the iterator for the source/dest couples,
+        excluding the couple where the destination is meant for the positive control.
         Sources and dests default to self._sources and self._dests"""
         sources = sources or self._sources
         dests = dests or self._dests_single
