@@ -31,11 +31,9 @@ class StationBTechnogenetics(StationB):
                  tempdeck_slot: str = '7',
                  tempdeck_temp: float = 55,
                  thermomixer_incubation_time: float = 5,
-                 tipracks_slots: Tuple[str, ...] = ('3', '6', '8', '9', '10'),
+                 tipracks_slots: Tuple[str, ...] = ('4', '6', '8', '9', '10'),
                  wash_1_vol: float = 680,
                  wash_2_vol: float = 680,
-                 wash_mix_aspiration_rate: float = 150,
-                 wash_mix_dispense_rate: float = 150,
                  **kwargs
                  ):
         """ Build a :py:class:`.StationBTechnogenetics`.
@@ -67,8 +65,6 @@ class StationBTechnogenetics(StationB):
             tipracks_slots=tipracks_slots,
             wash_1_vol=wash_1_vol,
             wash_2_vol=wash_2_vol,
-            wash_mix_aspiration_rate=wash_mix_aspiration_rate,
-            wash_mix_dispense_rate=wash_mix_dispense_rate,
             **kwargs
         )
         self._external_deepwell_incubation = external_deepwell_incubation
@@ -89,7 +85,7 @@ class StationBTechnogenetics(StationB):
     
     @labware_loader(5, "_flatplate")
     def load_flatplate(self):
-        self._flatplate = self._ctx.load_labware('opentrons_96_aluminumblock_nest_wellplate_100ul', '1', 'chilled elution plate on block for Station C')
+        self._flatplate = self._ctx.load_labware('opentrons_96_aluminumblock_nest_wellplate_100ul', '3', 'chilled elution plate on block for Station C')
     
     @labware_loader(5, "_tempplate")
     def load_tempplate(self):
